@@ -7,7 +7,7 @@ class TestPlot():
 
     @classmethod
     def teardown_class(cls):
-        path = 'test/test.png'
+        path = 'test/test.svg'
         if os.path.exists(path): os.remove(path)
 
     def get_fit_for_fitting(self):
@@ -15,5 +15,5 @@ class TestPlot():
 
     def test_save(self):
         plot = Plot(fit=self.get_fit_for_fitting())
-        plot.save('test/test.png')
-        assert os.path.exists('test/test.png')
+        plot.save('test/test.svg')
+        assert os.path.exists('test/test.svg')
